<?php

namespace Drupal\video_toolbox\Plugin\Field\FieldWidget;

use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'video_toolbox_item' widget.
 *
 * @FieldWidget(
 *   id = "video_t_widget",
 *   label = @Translation("Video ID"),
 *   field_types = {
 *     "video_toolbox_item"
 *   }
 * )
 */
class VideoToolWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $value = $items[$delta]->value ?? '';
    $element += [
      '#type' => 'textfield',
      '#title' => $this->t('Video ID'),
      '#description' => $this->t('Insert the video ID'),
      '#default_value' => $value,
      '#autocomplete_route_name' => 'video_toolbox.autocomplete_videos',
      '#element_validate' => [
        [static::class, 'validate'],
      ],
    ];

    return ['value' => $element];
  }

  /**
   * Validate the color text field.
   */
  public static function validate($element, FormStateInterface $form_state) {
    $value = $element['#value'];
    if (!$value) {
      return;
    }
    $videogetter = \Drupal::service('video.get_service');
    $videos = $videogetter->getVideoInfo($value);

    if ($videos == []) {
      $form_state->setError($element, t('Your video ID is not valid'));
    }
  }

}
